@@ -6,15 +6,15 @@ use CGI::Lingua;
 
 =head1 NAME
 
-HTML::SocialMedia - Put social media links into your website
+HTML::SocialMedia - Put social media links onto your website
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =cut
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ lookups.
 This cache object is an object that understands get() and set() messages,
 such as an L<CHI> object.
 
-Takes optional parameter, which is a L<CGI::Lingua> object.
+Takes optional parameter lingua, which is a L<CGI::Lingua> object.
 
 =head1 SUBROUTINES/METHODS
 
@@ -169,12 +169,22 @@ sub as_string {
 
 	my %params = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
 
+	if($self->{_logger}) {
+		$self->{_logger}->trace('Entering as_string');
+	}
 	my $lingua = $self->{_lingua};
 
 	unless($self->{_alpha2}) {
 		my $alpha2 = $lingua->language_code_alpha2();
 		my $locale = $lingua->locale();	# Locale::Object::Country
 
+		if($self->{_logger}) {
+			if(defined($alpha2)) {
+				$self->{_logger}->debug("language_code_alpha2: $alpha2");
+			} else {
+				$self->{_logger}->debug('language_code_alpha2 returned undef');
+			}
+		}
 		if($alpha2) {
 			my $salpha2 = $lingua->sublanguage_code_alpha2();
 			if((!defined($salpha2)) && defined($locale)) {
@@ -187,6 +197,10 @@ sub as_string {
 				my @l = $locale->languages_official();
 				$alpha2 = lc($l[0]->code_alpha2()) . '_' . uc($locale->code_alpha2());
 			} else {
+				# Can't determine the area, i.e. is it en_GB or en_US?
+				if($self->{_logger}) {
+					$self->{_logger}->debug('Clearing the value of alpha2');
+				}
 				$alpha2 = undef;
 			}
 		}
@@ -205,8 +219,14 @@ sub as_string {
 			}
 			unless($alpha2) {
 				$alpha2 = 'en_GB';
+				if($self->{_logger}) {
+					$self->{_logger}->info("Can't determine country, falling back to en_GB");
+				}
 			}
 		}
+		if($self->{_logger}) {
+			$self->{_logger}->debug("alpha2: $alpha2");
+		}
 		$self->{_alpha2} = $alpha2;
 	}
 
@@ -220,7 +240,7 @@ sub as_string {
 			# I suppose we could enuerate through other requested languages,
 			# but that is probably not worth the effort.
 
-			my $country = 'en_US';
+			my $country = $self->{_alpha2} || 'en_US';
 			my $res;
 			if($self->{_cache}) {
 				$res = $self->{_cache}->get($country);
@@ -236,10 +256,9 @@ sub as_string {
 
 				my $response;
 
-				$country = $self->{_alpha2};
 				eval {
 					$response = LWP::UserAgent->new(timeout => 10)->request(
-						HTTP::Request->new(GET => "http://connect.facebook.net/$country/sdk.js")
+						HTTP::Request->new(GET => "http://connect.facebook.com/$country/sdk.js")
 					);
 				};
 				if($@) {
@@ -277,7 +296,7 @@ sub as_string {
 					var js, fjs = d.getElementsByTagName(s)[0];
 					if (d.getElementById(id)) return;
 					js = d.createElement(s); js.id = id;
-					js.src = "//connect.facebook.net/$self->{_country}/sdk.js#xfbml=1&version=v2.8&appId=953901534714390";
+					js.src = "//connect.facebook.com/$self->{_country}/sdk.js#xfbml=1&version=v2.8&appId=953901534714390";
 					fjs.parentNode.insertBefore(js, fjs);
 				}(document, 'script', 'facebook-jssdk'));
 			</script>
